@@ -1,5 +1,5 @@
 package Text::MicroMason;
-$VERSION = 1.992;
+$VERSION = '1.993';
 
 require 5.0; # The tests use the new subref->() syntax, but the module doesn't
 use strict;
@@ -96,25 +96,32 @@ You can import various functions if you prefer to avoid method calls:
 Text::MicroMason interpolates blocks of Perl code embedded into text
 strings.
 
-Each MicroMason object acts as a "template compiler," which converts templates from text-with-embedded-code formats into ready-to-execute Perl subroutines.
+Each MicroMason object acts as a "template compiler," which converts
+templates from text-with-embedded-code formats into ready-to-execute
+Perl subroutines.
 
 =head2 MicroMason Initialization
 
-Use the new() method to create a Text::MicroMason object with the appropriate mixins and attributes.
+Use the new() method to create a Text::MicroMason object with the
+appropriate mixins and attributes.
 
   $mason = Text::MicroMason->new( %attribs );
 
-You may pass attributes as key-value pairs to the new() method to save various options for later use by the compile() method. 
+You may pass attributes as key-value pairs to the new() method to save
+various options for later use by the compile() method.
 
 =head2 Template Compilation
 
-To compile a text template, pass it to the compile() method to produce a new Perl subroutine to be returned as a code reference:
+To compile a text template, pass it to the compile() method to produce a
+new Perl subroutine to be returned as a code reference:
 
   $code_ref = $mason->compile( $type => $source, %attribs );
 
-Any attributes provided to compile() will temporarily override the persistant options defined by new(), for that template only.
+Any attributes provided to compile() will temporarily override the
+persistant options defined by new(), for that template only.
 
-You can provide the template as a text string, as an array of text lines, or as a file name or handle:
+You can provide the template as a text string, as an array of text
+lines, or as a file name or handle:
 
   $code_ref = $mason->compile( text => $template );
   $code_ref = $mason->compile( text => \$template );
@@ -123,15 +130,19 @@ You can provide the template as a text string, as an array of text lines, or as
   $code_ref = $mason->compile( handle => $fh );
   $code_ref = $mason->compile( handle => \*FILE );
 
-Template files are just plain text files that contains the string to be parsed. The files may have any name and extension you wish. The filename specified can either be absolute or relative to the program's current directory.
+Template files are just plain text files that contains the string to be
+parsed. The files may have any name and extension you wish. The filename
+specified can either be absolute or relative to the program's current
+directory.
 
 =head2 Template Execution
 
-To execute the template and obtain the output, call a compiled function: 
+To execute the template and obtain the output, call a compiled function:
 
   $result = $code_ref->( @arguments );
 
-(Note that the $code_ref->() syntax is unavailable in older versions of Perl; use the equivalent &$code_ref() syntax instead.)
+(Note that the $code_ref->() syntax is unavailable in older versions of
+Perl; use the equivalent &$code_ref() syntax instead.)
 
 As a shortcut, the execute method compiles and runs the template one time:
 
@@ -140,13 +151,15 @@ As a shortcut, the execute method compiles and runs the template one time:
 
 =head2 Argument Passing
 
-You can pass arguments to a template subroutine using positional or named arguments. 
+You can pass arguments to a template subroutine using positional or
+named arguments.
 
-For positional arguments, pass the argument list and read from @_ as usual: 
+For positional arguments, pass the argument list and read from @_ as usual:
 
   $mason->compile( text=>'Hello <% shift(@_) %>.' )->( 'Dave' );
 
-For named arguments, pass in a hash of key-value pairs to be made accessible in an C<%ARGS> hash within the template subroutine:
+For named arguments, pass in a hash of key-value pairs to be made
+accessible in an C<%ARGS> hash within the template subroutine:
 
   $mason->compile( text=>'Hello <% $ARGS{name} %>.' )->( name=>'Dave' );
 
@@ -160,24 +173,40 @@ Arguments passed to new() that begin with a dash will be added as mixin classes.
 
   $mason = Text::MicroMason->new( -Mixin1, %attribs, -Mixin2 );
 
-Every MicroMason object inherits from an abstract Base class and some set of mixin classes. By combining mixins you can create subclasses with the desired combination of features. See L<Text::MicroMason::Base> for documentation of the base class, including private methods and extension mechanisms.
+Every MicroMason object inherits from an abstract Base class and some
+set of mixin classes. By combining mixins you can create subclasses with
+the desired combination of features. See L<Text::MicroMason::Base> for
+documentation of the base class, including private methods and extension
+mechanisms.
 
-If you call the new method on Text::MicroMason, it automatically includes the HTMLMason mixin, which provides the standard template syntax. If you want to create an object without the default HTMLMason functionality, call Text::MicroMason::Base->new() instead. 
+If you call the new method on Text::MicroMason, it automatically
+includes the HTMLMason mixin, which provides the standard template
+syntax. If you want to create an object without the default HTMLMason
+functionality, call Text::MicroMason::Base->new() instead.
 
-Some mixins define the syntax for a particular template format. You will generally need to select one, and only one, of the mixins listed in L</"TEMPLATE SYNTAXES">.
+Some mixins define the syntax for a particular template format. You will
+generally need to select one, and only one, of the mixins listed in
+L</"TEMPLATE SYNTAXES">.
 
-Other mixins provide optional functionality. Those mixins may define additional public methods, and may support or require values for various additional attributes. For a list of such mixin classes, see L</"MIXIN FEATURES">.
+Other mixins provide optional functionality. Those mixins may define
+additional public methods, and may support or require values for various
+additional attributes. For a list of such mixin classes, see L</"MIXIN
+FEATURES">.
 
 
 =head1 TEMPLATE SYNTAXES
 
-Templates contain a mix of literal text to be output with some type of markup syntax which specifies more complex behaviors.
+Templates contain a mix of literal text to be output with some type of
+markup syntax which specifies more complex behaviors.
 
-The Text::MicroMason::HTMLMason mixin is selected by default. To enable an alternative, pass its name to Text::MicroMason::Base->new( -MixinName ). 
+The Text::MicroMason::HTMLMason mixin is selected by default. To enable
+an alternative, pass its name to Text::MicroMason::Base->new( -
+MixinName ).
 
 =head2 HTMLMason
 
-The HTMLMason mixin provides lexer and assembler methods that handle most elements of HTML::Mason's template syntax.
+The HTMLMason mixin provides lexer and assembler methods that handle
+most elements of HTML::Mason's template syntax.
 
   my $mason = Text::MicroMason::Base->new( -HTMLMason );
   my $output = $mason->execute( text => $template, name => 'Bob' );
@@ -206,7 +235,8 @@ For a definition of the template syntax, see L<Text::MicroMason::HTMLMason>.
 
 =head2 DoubleQuote
 
-The DoubleQuote mixin uses Perl's double-quoting interpolation as a minimalist syntax for templating.
+The DoubleQuote mixin uses Perl's double-quoting interpolation as a
+minimalist syntax for templating.
 
   my $mason = Text::MicroMason::Base->new( -DoubleQuote );
   my $output = $mason->execute( text => $template, name => 'Bob' );
@@ -220,7 +250,8 @@ For more information see L<Text::MicroMason::DoubleQuote>.
 
 =head2 Embperl
 
-The Embperl mixin support a template syntax similar to that used by the HTML::Embperl module.
+The Embperl mixin support a template syntax similar to that used by the
+HTML::Embperl module.
 
   my $mason = Text::MicroMason::Base->new( -Embperl );
   my $output = $mason->execute( text => $template, name => 'Bob' );
@@ -240,7 +271,8 @@ For more information see L<Text::MicroMason::Embperl>.
 
 =head2 HTMLTemplate
 
-The HTMLTemplate mixin supports a syntax similar to that used by the HTML::Template module.
+The HTMLTemplate mixin supports a syntax similar to that used by the
+HTML::Template module.
 
   my $mason = Text::MicroMason::Base->new( -HTMLTemplate );
   my $output = $mason->execute( text => $template, name => 'Bob' );
@@ -259,7 +291,8 @@ For more information see L<Text::MicroMason::HTMLTemplate>.
 
 =head2 ServerPages
 
-The ServerPages mixin supports a syntax similar to that used by the Apache::ASP module.
+The ServerPages mixin supports a syntax similar to that used by the
+Apache::ASP module.
 
   my $mason = Text::MicroMason::Base->new( -ServerPages );
   my $output = $mason->execute( text => $template, name => 'Bob' );
@@ -289,7 +322,8 @@ For more information see L<Text::MicroMason::Sprintf>.
 
 =head2 TextTemplate
 
-The TextTemplate mixin supports a syntax similar to that used by the Text::Template module.
+The TextTemplate mixin supports a syntax similar to that used by the
+Text::Template module.
 
   my $mason = Text::MicroMason::Base->new( -TextTemplate );
   my $output = $mason->execute( text => $template, name => 'Bob' );
@@ -304,7 +338,8 @@ For more information see L<Text::MicroMason::TextTemplate>.
 
 =head1 MIXIN FEATURES
 
-The following mixin classes can be layered on to your MicroMason object to provide additional functionality. 
+The following mixin classes can be layered on to your MicroMason object
+to provide additional functionality.
 
 To add a mixin's functionality, pass it's name with a dash to the new() method:
 
@@ -318,8 +353,9 @@ For details see L<Text::MicroMason::AllowGlobals>.
 
 =head2 CatchErrors
 
-Both compilation and run-time errors in your template are handled as fatal
-exceptions. To prevent a template error from ending your program, enclose it in an eval block:
+Both compilation and run-time errors in your template are handled as
+fatal exceptions. To prevent a template error from ending your program,
+enclose it in an eval block:
 
   my $result = eval { $mason->execute( text => $template ) };
   if ( $@ ) {
@@ -328,39 +364,50 @@ exceptions. To prevent a template error from ending your program, enclose it in
     print $result;
   }
 
-To transparently add this functionality to your MicroMason object, see L<Text::MicroMason::CatchErrors>.
+To transparently add this functionality to your MicroMason object, see
+L<Text::MicroMason::CatchErrors>.
 
 =head2 CompileCache
 
-Calling execute repeatedly will be slower than compiling once and calling the template function repeatedly, unless you enable compilation caching. 
+Calling execute repeatedly will be slower than compiling once and
+calling the template function repeatedly, unless you enable
+compilation caching.
 
 For details see L<Text::MicroMason::CompileCache>.
 
 =head2 Debug
 
-When trying to debug a template problem, it can be helpful to watch the internal  processes of template compilation. This mixin adds controllable warning messages that show the intermediate parse information.
+When trying to debug a template problem, it can be helpful to watch the
+internal processes of template compilation. This mixin adds controllable
+warning messages that show the intermediate parse information.
 
 For details see L<Text::MicroMason::Debug>.
 
 =head2 ExecuteCache
 
-Each time you execute the template all of the logic will be re-evaluated, unless you enable execution caching, which stores the output of each template for each given set of arguments. 
+Each time you execute the template all of the logic will be re-
+evaluated, unless you enable execution caching, which stores the output
+of each template for each given set of arguments.
 
 For details see L<Text::MicroMason::ExecuteCache>.
 
 =head2 Filters
 
-HTML::Mason provides an expression filtering mechanism which is typically used for applying HTML and URL escaping functions to output. 
+HTML::Mason provides an expression filtering mechanism which is
+typically used for applying HTML and URL escaping functions to output.
 
   Text::MicroMason->new(-Filters)->compile( text => $template );
 
   <p> Hello <% $name |h %>!
 
-The Filters mixin provides this capability for Text::MicroMason templates. To select it, add its name to your Mason initialization call:
+The Filters mixin provides this capability for Text::MicroMason
+templates. To select it, add its name to your Mason initialization call:
 
   my $mason = Text::MicroMason->new( -Filters );
 
-Output expressions may then be followed by "|h" or "|u" escapes; for example this line would convert any ampersands in the output to the equivalent HTML entity:
+Output expressions may then be followed by "|h" or "|u" escapes; for
+example this line would convert any ampersands in the output to the
+equivalent HTML entity:
 
   Welcome to <% $company_name |h %>
 
@@ -368,29 +415,49 @@ For more information see L<Text::MicroMason::Filters>.
 
 =head2 PassVariables
 
-Allows you to pass arguments to templates as variables instead of the basic argument list. 
+Allows you to pass arguments to templates as variables instead of the
+basic argument list.
 
 For details see L<Text::MicroMason::PostProcess>.
 
 =head2 PostProcess
 
-Allows you to specify one or more functions through which all template output should be passed before it is returned. 
+Allows you to specify one or more functions through which all template
+output should be passed before it is returned.
 
 For details see L<Text::MicroMason::PostProcess>.
 
 =head2 Safe
 
-By default, the code embedded in a template has accss to all of the capabilities of your Perl process, and could potentially perform dangerous activities such as accessing or modifying files and starting other programs. 
+By default, the code embedded in a template has accss to all of the
+capabilities of your Perl process, and could potentially perform
+dangerous activities such as accessing or modifying files and starting
+other programs.
 
-If you need to execute untrusted templates, use the Safe module, which can restrict the operations and data structures that template code can access.
+If you need to execute untrusted templates, use the Safe module,
+which can restrict the operations and data structures that template
+code can access.
 
-To add this functionality to your MicroMason object, see L<Text::MicroMason::Safe>.
+To add this functionality to your MicroMason object, see
+L<Text::MicroMason::Safe>.
 
 =head2 TemplateDir
 
-The filenames passed to the compile() or execute() methods can be looked up relative to a base directory path or  the current template file. 
+The filenames passed to the compile() or execute() methods can be looked
+up relative to a base directory path or the current template file.
 
-To add this functionality to your MicroMason object, see L<Text::MicroMason::TemplateDir>.
+To add this functionality to your MicroMason object, see
+L<Text::MicroMason::TemplateDir>.
+
+=head2 TemplatePath
+
+The filenames passed to the compile() or execute() methods are looked up
+relative to a list of multiple base directory paths, in order. It tries
+as hard as possible to maintain compatibility with caching and <& &>
+template includes.
+
+To add this functionality to your MicroMason object, see
+L<Text::MicroMason::TemplatePath>.
 
 
 =head1 OTHER INTERFACES
@@ -399,7 +466,9 @@ To add this functionality to your MicroMason object, see L<Text::MicroMason::Tem
 
 Importable functions are provided for users who prefer a procedural interface. 
 
-The supported functions are listed in L<Text::MicroMason::Functions>. (For backwards compatibility, those functions can also be imported from the main Text::MicroMason package.) 
+The supported functions are listed in L<Text::MicroMason::Functions>.
+(For backwards compatibility, those functions can also be imported from
+the main Text::MicroMason package.)
 
 =head2 Template Frameworks
 
@@ -415,7 +484,8 @@ For more information, see L<Inline::Mason>.
 
 =head1 DIAGNOSTICS
 
-The following diagnostic messages are produced for the indicated error conditions (where %s indicates variable message text):
+The following diagnostic messages are produced for the indicated error
+conditions (where %s indicates variable message text):
 
 =over 4
 
@@ -423,45 +493,60 @@ The following diagnostic messages are produced for the indicated error condition
 
 MicroMason parsing halted at %s
 
-Indicates that the parser was unable to finish tokenising the source text. Generally this means that there is a bug somewhere in the regular expressions used by lex(). 
+Indicates that the parser was unable to finish tokenising the source
+text. Generally this means that there is a bug somewhere in the regular
+expressions used by lex().
 
-(If you encounter this error, please feel free to file a bug report or send an example of the error to the author using the addresses below, and I'll attempt to correct it in a future release.)
+(If you encounter this error, please feel free to file a bug report or
+send an example of the error to the author using the addresses below,
+and I'll attempt to correct it in a future release.)
 
 =item *
 
 MicroMason compilation failed: %s
 
-The template was parsed succesfully, but the Perl subroutine declaration it was converted to failed to compile. This is generally a result of a syntax error in one of the Perl expressions used within the template. 
+The template was parsed succesfully, but the Perl subroutine declaration
+it was converted to failed to compile. This is generally a result of a
+syntax error in one of the Perl expressions used within the template.
 
 =item * 
 
 Error in template subroutine: %s
 
-Additional diagnostic for compilation errors, showing the text of the subroutine which failed to compile.
+Additional diagnostic for compilation errors, showing the text of the
+subroutine which failed to compile.
 
 =item * 
 
 Error in template file %s, interpreted as: %s
 
-Additional diagnostic for compilation errors in external files, showing the filename and the text of the subroutine which failed to compile.
+Additional diagnostic for compilation errors in external files, showing
+the filename and the text of the subroutine which failed to compile.
 
 =item * 
 
 MicroMason execution failed: %s
 
-After parsing and compiling the template succesfully, the subroutine was run and caused a fatal exception, generally because that some Perl code used within the template caused die() to be called (or an equivalent function like croak or confess).
+After parsing and compiling the template succesfully, the subroutine was
+run and caused a fatal exception, generally because that some Perl code
+used within the template caused die() to be called (or an equivalent
+function like croak or confess).
 
 =item *
 
 MicroMason: filename is missing or empty
 
-One of the compile or execute methods was called with an empty or undefined filename, or one of the compile_file or execute_file methods was called with no arguments.
+One of the compile or execute methods was called with an empty or
+undefined filename, or one of the compile_file or execute_file methods
+was called with no arguments.
 
 =item *
 
 MicroMason can't read from %s: %s
 
-One of the compile_file or execute_file functions was called but we were unable to read the requested file, because the file path is incorrect or we have insufficient priveleges to read that file.
+One of the compile_file or execute_file functions was called but we were
+unable to read the requested file, because the file path is incorrect or
+we have insufficient priveleges to read that file.
 
 =back
 
